@@ -1,5 +1,4 @@
-evaldiag.bifd <- function(evalarg, bifdobj, sLfd=int2Lfd(0), tLfd=int2Lfd(0), 
-                            returnMatrix=FALSE)
+evaldiag.bifd <- function(evalarg, bifdobj, sLfd=int2Lfd(0), tLfd=int2Lfd(0))
 {
 #  EVALDIAG_BIFD  evaluates a bi-functional data object BIFD
 #  with both argument values in array EVALARG.
@@ -9,11 +8,8 @@ evaldiag.bifd <- function(evalarg, bifdobj, sLfd=int2Lfd(0), tLfd=int2Lfd(0),
 
 #  last modified 2008(?) replacing Matlab subscripts with R style
 # in lines 70, 77, 78;  previously modified 26 October 2005
-#  RETURNMATRIX ... If False, a matrix in sparse storage model can be returned
-#               from a call to function BsplineS.  See this function for
-#               enabling this option.
 
-#  Last modified 8 May 2012 by Jim Ramsay
+#  Last modified 6 January 2020 by Jim Ramsay
 
 #  exchange order if BIFD is the first argument
 if (inherits(evalarg, "bifd")) {
@@ -53,12 +49,12 @@ tLfd <- int2Lfd(tLfd)
 #  compute the basis matrix for SBASISOBJ
 
 snderiv   <- sLfd$nderiv
-sbasismat <- eval.basis(evalarg, sbasisobj, sLfd, returnMatrix)
+sbasismat <- eval.basis(evalarg, sbasisobj, sLfd)
 
 #  compute the basis matrix for tBASISOBJ
 
 tnderiv   <- tLfd$nderiv
-tbasismat <- eval.basis(evalarg, tbasisobj, tLfd, returnMatrix)
+tbasismat <- eval.basis(evalarg, tbasisobj, tLfd)
 
 #  Extract the coefficient matrix
 
